# -*- coding: UTF-8 -*

"""Notes, décisions de jury, évènements scolaires
"""

from app import db
from app.models import SHORT_STR_LEN
from app.models import CODE_STR_LEN


class ScolarFormSemestreValidation(db.Model):
    """Décisions de jury"""

    __tablename__ = "scolar_formsemestre_validation"
    # Assure unicité de la décision:
    __table_args__ = (db.UniqueConstraint("etudid", "formsemestre_id", "ue_id"),)

    id = db.Column(db.Integer, primary_key=True)
    formsemestre_validation_id = db.synonym("id")
    etudid = db.Column(
        db.Integer,
        db.ForeignKey("identite.id"),
        index=True,
    )
    formsemestre_id = db.Column(
        db.Integer,
        db.ForeignKey("notes_formsemestre.id"),
        index=True,
    )
    ue_id = db.Column(
        db.Integer,
        db.ForeignKey("notes_ue.id"),
        index=True,
    )
    code = db.Column(db.String(CODE_STR_LEN), nullable=False, index=True)
    # NULL pour les UE, True|False pour les semestres:
    assidu = db.Column(db.Boolean)
    event_date = db.Column(db.DateTime(timezone=True), server_default=db.func.now())
    # NULL sauf si compense un semestre:
    compense_formsemestre_id = db.Column(
        db.Integer,
        db.ForeignKey("notes_formsemestre.id"),
    )
    moy_ue = db.Column(db.Float)
    # (normalement NULL) indice du semestre, utile seulement pour
    # UE "antérieures" et si la formation définit des UE utilisées
    # dans plusieurs semestres (cas R&T IUTV v2)
    semestre_id = db.Column(db.Integer)
    # Si UE validée dans le cursus d'un autre etablissement
    is_external = db.Column(
        db.Boolean, default=False, server_default="false", index=True
    )

    ue = db.relationship("UniteEns", lazy="select", uselist=False)

    def __repr__(self):
        return f"{self.__class__.__name__}({self.formsemestre_id}, {self.etudid}, code={self.code}, ue={self.ue_id}, moy_ue={self.moy_ue})"


class ScolarAutorisationInscription(db.Model):
    """Autorisation d'inscription dans un semestre"""

    __tablename__ = "scolar_autorisation_inscription"
    id = db.Column(db.Integer, primary_key=True)
    autorisation_inscription_id = db.synonym("id")

    etudid = db.Column(
        db.Integer,
        db.ForeignKey("identite.id"),
    )
    formation_code = db.Column(db.String(SHORT_STR_LEN), nullable=False)
    # semestre ou on peut s'inscrire:
    semestre_id = db.Column(db.Integer)
    date = db.Column(db.DateTime(timezone=True), server_default=db.func.now())
    origin_formsemestre_id = db.Column(
        db.Integer,
        db.ForeignKey("notes_formsemestre.id"),
    )


class ScolarEvent(db.Model):
    """Evenement dans le parcours scolaire d'un étudiant"""

    __tablename__ = "scolar_events"
    id = db.Column(db.Integer, primary_key=True)
    event_id = db.synonym("id")
    etudid = db.Column(
        db.Integer,
        db.ForeignKey("identite.id"),
    )
    event_date = db.Column(db.DateTime(timezone=True), server_default=db.func.now())
    formsemestre_id = db.Column(
        db.Integer,
        db.ForeignKey("notes_formsemestre.id"),
    )
    ue_id = db.Column(
        db.Integer,
        db.ForeignKey("notes_ue.id"),
    )
    # 'CREATION', 'INSCRIPTION', 'DEMISSION',
    # 'AUT_RED', 'EXCLUS', 'VALID_UE', 'VALID_SEM'
    # 'ECHEC_SEM'
    # 'UTIL_COMPENSATION'
    event_type = db.Column(db.String(SHORT_STR_LEN))
    # Semestre compensé par formsemestre_id:
    comp_formsemestre_id = db.Column(
        db.Integer,
        db.ForeignKey("notes_formsemestre.id"),
    )
