# -*- coding: utf-8 -*-

"""Test Logos

Utilisation :
    créer les variables d'environnement: (indiquer les valeurs
    pour le serveur ScoDoc que vous voulez interroger)

    export SCODOC_URL="https://scodoc.xxx.net/"
    export SCODOC_USER="xxx"
    export SCODOC_PASSWD="xxx"
    export CHECK_CERTIFICATE=0 # ou 1 si serveur de production avec certif SSL valide

    (on peut aussi placer ces valeurs dans un fichier .env du répertoire tests/api).

    Lancer :
        pytest tests/api/test_api_formsemestre.py
"""

import requests

from tests.api.setup_test_api import SCODOC_URL, CHECK_CERTIFICATE, HEADERS
from tests.api.tools_test_api import verify_fields

# formsemestre
def test_formsemestre():
    r = requests.get(
        SCODOC_URL + "/ScoDoc/api/formsemestre/1",
        headers=HEADERS,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200

    formsemestre = r.json()

    fields = [
        "date_fin",
        "resp_can_edit",
        "dept_id",
        "etat",
        "resp_can_change_ens",
        "id",
        "modalite",
        "ens_can_edit_eval",
        "formation_id",
        "gestion_compensation",
        "elt_sem_apo",
        "semestre_id",
        "bul_hide_xml",
        "elt_annee_apo",
        "titre",
        "block_moyennes",
        "scodoc7_id",
        "date_debut",
        "gestion_semestrielle",
        "bul_bgcolor",
        "formsemestre_id",
        "titre_num",
        "date_debut_iso",
        "date_fin_iso",
        "responsables",
    ]

    fields_OK = verify_fields(formsemestre, fields)

    assert fields_OK is True


# etudiant_bulletin
def test_etudiant_bulletin():
    r = requests.get(
        SCODOC_URL + "/ScoDoc/api/formsemestre/1/etudiant/etudid/1/bulletin",
        headers=HEADERS,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200

    r = requests.get(
        SCODOC_URL + "/ScoDoc/api/formsemestre/1/etudiant/nip/1/bulletin",
        headers=HEADERS,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200

    r = requests.get(
        SCODOC_URL + "/ScoDoc/api/formsemestre/1/etudiant/ine/1/bulletin",
        headers=HEADERS,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200


# bulletins
def test_bulletins():
    r = requests.get(
        SCODOC_URL + "/ScoDoc/api/formsemestre/1/bulletins",
        headers=HEADERS,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200


# # jury
# def test_jury():
#     r = requests.get(
#         SCODOC_URL + "/ScoDoc/api/formsemestre/1/jury",
#         headers=HEADERS,
#         verify=CHECK_CERTIFICATE,
#     )
#     assert r.status_code == 200

# semestre_index
def test_semestre_index():

    ue_fields = [
        "semestre_idx",
        "type",
        "formation_id",
        "ue_code",
        "id",
        "ects",
        "acronyme",
        "is_external",
        "numero",
        "code_apogee",
        "titre",
        "coefficient",
        "color",
        "ue_id",
    ]

    ressource_fields = [
        "heures_tp",
        "code_apogee",
        "titre",
        "coefficient",
        "module_type",
        "id",
        "ects",
        "abbrev",
        "ue_id",
        "code",
        "formation_id",
        "heures_cours",
        "matiere_id",
        "heures_td",
        "semestre_id",
        "numero",
        "module_id",
    ]

    sae_fields = [
        "heures_tp",
        "code_apogee",
        "titre",
        "coefficient",
        "module_type",
        "id",
        "ects",
        "abbrev",
        "ue_id",
        "code",
        "formation_id",
        "heures_cours",
        "matiere_id",
        "heures_td",
        "semestre_id",
        "numero",
        "module_id",
    ]

    r = requests.get(
        SCODOC_URL + "/ScoDoc/api/formsemestre/1/programme",
        headers=HEADERS,
        verify=CHECK_CERTIFICATE,
    )
    assert r.status_code == 200
    assert len(r.json()) == 3

    ue = r.json()["ues"][0]
    ressource = r.json()["ressources"][0]
    sae = r.json()["saes"][0]

    fields_ue_OK = verify_fields(ue, ue_fields)
    fields_ressource_OK = verify_fields(ressource, ressource_fields)
    fields_sae_OK = verify_fields(sae, sae_fields)

    assert fields_ue_OK is True
    assert fields_ressource_OK is True
    assert fields_sae_OK is True
